package com.webchat.pgc.messagequeue.consumer;

import com.webchat.common.enums.messagequeue.MessageBroadChannelEnum;
import com.webchat.common.enums.messagequeue.MessageQueueEnum;
import com.webchat.common.service.messagequeue.consumer.AbstractRedisDelayQueueConsumer;
import com.webchat.common.service.messagequeue.producer.MessageQueueProducer;
import com.webchat.common.util.JsonUtil;
import com.webchat.domain.dto.queue.ArticleDelayMessageDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Set;

/**
 * 公众号推送MQ消费
 */
@Service
public class ArticlePushDelayQueueConsumer extends AbstractRedisDelayQueueConsumer<ArticleDelayMessageDTO> {

    @Autowired
    private MessageQueueProducer<Set<String>, Long> messageQueueProducer;

    @Override
    protected ArticleDelayMessageDTO convert(String s) {

        return JsonUtil.fromJson(s, ArticleDelayMessageDTO.class);
    }

    @Override
    protected MessageQueueEnum getMessageQueue() {

        return MessageQueueEnum.QUEUE_OFFICIAL_ARTICLE_PUSH_MESSAGE;
    }

    @Override
    protected void doNextConsume(Set<String> messages) {

        /**
         * 广播通知connect service完成推文、以及消息持久化，批量提交任务到普通队列
         */
        messageQueueProducer.broadSend(MessageBroadChannelEnum.QUEUE_ARTICLE_PUSH_MESSAGE, messages);
    }
}
